==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/plugins/external_tool_support/src/blast_plus/RPSBlastSupportTask.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "RPSBlastSupportTask.h"
#include "BlastPlusSupport.h"


namespace U2 {

ExternalToolRunTask* RPSBlastSupportTask::createBlastPlusTask() {
    QStringList arguments;
    arguments << "-db" << settings.databaseNameAndPath;
    arguments << "-evalue" << QString::number(settings.expectValue);
    arguments << "-query" << url;
    arguments << "-outfmt" << "5"; //Set output file format to xml
    arguments << "-out" << url+".xml"; //settings.outputRepFile;

    algoLog.trace("RPSBlast arguments: "+arguments.join(" "));
    logParser=new ExternalToolLogParser;
    QString workingDirectory=QFileInfo(url).absolutePath();
    return new ExternalToolRunTask(RPSBLAST_TOOL_NAME, arguments, logParser, workingDirectory);
}

LocalCDSearch::LocalCDSearch(const CDSearchSettings& settings) {
    BlastTaskSettings stngs;
    stngs.databaseNameAndPath = settings.localDbFolder + "/" + settings.dbName;
    stngs.querySequence = settings.query;
    stngs.expectValue = settings.ev;
    stngs.alphabet = settings.alp;
    stngs.needCreateAnnotations = false;
    task = new RPSBlastSupportTask(stngs);
}

QList<SharedAnnotationData> LocalCDSearch::getCDSResults() const {
    return task->getResultedAnnotations();
}

} //namespace

==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/plugins/external_tool_support/src/blast_plus/RPSBlastSupportTask.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include <QtCore/QFileInfo>

#include "RPSBlastSupportTask.h"
#include "BlastPlusSupport.h"

namespace U2 {

ExternalToolRunTask* RPSBlastSupportTask::createBlastPlusTask() {
    QStringList arguments;
    arguments << "-db" << settings.databaseNameAndPath;
    arguments << "-evalue" << QString::number(settings.expectValue);
    arguments << "-query" << url;
    arguments << "-outfmt" << "5"; //Set output file format to xml
    arguments << "-out" << url+".xml"; //settings.outputRepFile;

    algoLog.trace("RPSBlast arguments: "+arguments.join(" "));
    QString workingDirectory = QFileInfo(url).absolutePath();
    ExternalToolRunTask* runTask = new ExternalToolRunTask(ET_RPSBLAST, arguments, new ExternalToolLogParser(), workingDirectory);
    setListenerForTask(runTask);
    return runTask;
}

LocalCDSearch::LocalCDSearch(const CDSearchSettings& settings) {
    BlastTaskSettings stngs;
    stngs.databaseNameAndPath = settings.localDbFolder + "/" + settings.dbName;
    stngs.querySequence = settings.query;
    stngs.expectValue = settings.ev;
    stngs.alphabet = settings.alp;
    stngs.needCreateAnnotations = false;
    task = new RPSBlastSupportTask(stngs);
}

QList<SharedAnnotationData> LocalCDSearch::getCDSResults() const {
    return task->getResultedAnnotations();
}

} //namespace
